# Enable to make the appliance use virtio_blk
# Default is enabled
%if %{defined libguestfs_virtio}
%global with_virtio %{libguestfs_virtio}
%else
%global with_virtio 1
%endif 

# Enable to run tests during check
# Default is enabled
%if %{defined libguestfs_runtests}
%global runtests %{libguestfs_runtests}
%else
%global runtests 0
%endif

Summary:       Access and modify virtual machine disk images
Name:          libguestfs
Epoch:         1
Version:       1.24.5
%define subrel 1
Release:       %mkrel 1
License:       LGPLv2+
Group:         System/Libraries
URL:           http://libguestfs.org/
Source0:       http://libguestfs.org/download/1.24-stable/%{name}-%{version}.tar.gz
Patch0:        libguestfs-1.23.13-mga-automake-selinux.patch
Patch1:        libguestfs-1.23.13-mga-packagelist.patch
Patch2:        libguestfs-1.23.13-mga-lua.patch

BuildRequires: perl
BuildRequires: iurt
BuildRequires: hivex-devel >= 1.2.2
BuildRequires: augeas-devel >= 0.5.0
BuildRequires: augeas >= 0.5.0
BuildRequires: readline-devel
BuildRequires: cdrkit-genisoimage
BuildRequires: libxml2-devel
BuildRequires: qemu >= 0.10
#BuildRequires: createrepo
BuildRequires: selinux-devel
BuildRequires: pcre-devel
BuildRequires: file-devel
BuildRequires: libvirt-devel
BuildRequires: po4a
BuildRequires: ncurses-devel
BuildRequires: lvm2, ntfs-3g, util-linux-ng
BuildRequires: makedev, net-tools, file
BuildRequires: module-init-tools, procps, strace, iputils
BuildRequires: dosfstools, zerofree, lsof, scrub, libselinux
BuildRequires: parted, e2fsprogs, btrfs-progs, gfs2-utils
BuildRequires: hfsplus-tools, nilfs-utils, reiserfs-utils
BuildRequires: jfsutils, xfsprogs
BuildRequires: vim-minimal
BuildRequires: cryptsetup-luks
BuildRequires: grub, ntfsprogs
BuildRequires: ocaml
BuildRequires: ocaml-findlib-devel
BuildRequires: ocaml-xml-light-devel
BuildRequires: perl-devel
BuildRequires: perl-Test-Simple
BuildRequires: perl-Test-Pod
BuildRequires: perl-Test-Pod-Coverage
BuildRequires: perl-ExtUtils-MakeMaker
BuildRequires: perl-String-ShellQuote
BuildRequires: perl-XML-Writer
BuildRequires: perl-libintl-perl
BuildRequires: python-devel
BuildRequires: ruby-devel
BuildRequires: ruby-rake
BuildRequires: java
BuildRequires: jpackage-utils
BuildRequires: java-devel
BuildRequires: php-devel
BuildRequires: php-cli
BuildRequires: ghc
BuildRequires: pkgconfig(lua)
BuildRequires: pkgconfig(bash-completion)
BuildRequires: pkgconfig(gobject-introspection-1.0)
BuildRequires: pkgconfig(libsystemd-journal)
BuildRequires: pkgconfig(fuse)
BuildRequires: pkgconfig(yajl)
BuildRequires: golang

# For libguestfs-tools:
BuildRequires: perl-Sys-Virt
BuildRequires: qemu-img

BuildRequires: supermin >= 4.1.3

# Runtime requires:
Requires:      qemu >= 0.12
Requires:      iurt
# in order to be able to mount disk images:
Requires:      supermin-helper

# For libguestfs-test-tool.
Requires:      cdrkit-genisoimage

Requires: libselinux-utils
Requires: nilfs-utils
Requires: hivex

BuildRequires: gperf
BuildRequires: erlang-compiler
BuildRequires: erlang-devel
BuildRequires: erlang-tools
BuildRequires: erlang-erl_interface

%description
Libguestfs is a library for accessing and modifying guest disk images.
Amongst the things this is good for: making batch configuration
changes to guests, getting disk used/free statistics (see also:
virt-df), migrating between virtualization systems (see also:
virt-p2v), performing partial backups, performing partial guest
clones, cloning guests and changing registry/UUID/hostname info, and
much else besides.

Libguestfs uses Linux kernel and qemu code, and can access any type of
guest filesystem that Linux and qemu can, including but not limited
to: ext2/3/4, btrfs, FAT and NTFS, LVM, many different disk partition
schemes, qcow, qcow2, vmdk.

Libguestfs provides ways to enumerate guest storage (eg. partitions,
LVs, what filesystem is in each LV, etc.).  It can also run commands
in the context of the guest.

%package devel
Summary:       Development tools and libraries for %{name}
Group:         System/Libraries
Requires:      %{name} = %{epoch}:%{version}-%{release}
Requires:      pkgconfig


%description devel
%{name}-devel contains development tools and libraries
for %{name}.


%package -n guestfish
Summary:       Shell for accessing and modifying virtual machine disk images
Group:         Development/Tools
License:       GPLv2+
Requires:      %{name} = %{epoch}:%{version}-%{release}
Requires:      perl
Requires:      hexedit


%description -n guestfish
Guestfish is the Filesystem Interactive SHell, for accessing and
modifying virtual machine disk images from the command line and shell
scripts.


%package mount
Summary:       Mount guest filesystems on the host using FUSE and libguestfs
Group:         Development/Tools
License:       GPLv2+
Requires:      %{name} = %{epoch}:%{version}-%{release}
Requires:      virt-inspector


%description mount
The guestmount command lets you mount guest filesystems on the
host using FUSE and %{name}.


%package tools
Summary:       System administration tools for virtual machines
Group:         Development/Tools
License:       GPLv2+
Requires:      %{name} = %{epoch}:%{version}-%{release}
Requires:      guestfish
Requires:      perl-Sys-Virt
Requires:      perl-String-ShellQuote
Requires:      perl-XML-Writer
Requires:      hivex >= 1.2.2
Requires:      qemu-img

# Obsolete and replace earlier packages.
Provides:      virt-cat = %{epoch}:%{version}-%{release}
Obsoletes:     virt-cat < %{epoch}:%{version}-%{release}
Provides:      virt-df = %{epoch}:%{version}-%{release}
Obsoletes:     virt-df < %{epoch}:%{version}-%{release}
Provides:      virt-inspector = %{epoch}:%{version}-%{release}
Obsoletes:     virt-inspector < %{epoch}:%{version}-%{release}

# RHBZ#514309
Provides:      virt-df2 = %{epoch}:%{version}-%{release}
Obsoletes:     virt-df2 < %{epoch}:%{version}-%{release}

# These were never packages:
Provides:      virt-edit = %{epoch}:%{version}-%{release}
Provides:      virt-rescue = %{epoch}:%{version}-%{release}


%description tools
This package contains miscellaneous system administrator command line
tools for virtual machines.

Virt-cat is a command line tool to display the contents of a file in a
virtual machine.

Virt-df is a command line tool to display free space on virtual
machine filesystems.  Unlike other tools, it doesn’t just display the
amount of space allocated to a virtual machine, but can look inside
the virtual machine to see how much space is really being used.  It is
like the df(1) command, but for virtual machines, except that it also
works for Windows virtual machines.

Virt-edit is a command line tool to edit the contents of a file in a
virtual machine.

Virt-inspector examines a virtual machine and tries to determine the
version of the OS, the kernel version, what drivers are installed,
whether the virtual machine is fully virtualized (FV) or
para-virtualized (PV), what applications are installed and more.

Virt-list-filesystems can be used to list out the filesystems in a
virtual machine image (for shell scripts etc).

Virt-list-partitions can be used to list out the partitions in a
virtual machine image.

Virt-ls is a command line tool to list out files in a virtual machine.

Virt-make-fs is a command line tool to build a filesystem out of
a collection of files or a tarball.

Virt-rescue provides a rescue shell for making interactive,
unstructured fixes to virtual machines.

Virt-resize can resize existing virtual machine disk images.

Virt-tar is an archive, backup and upload tool for virtual machines.

Virt-win-reg lets you look inside the Windows Registry for
Windows virtual machines.


%package -n ocaml-%{name}
Summary:       OCaml bindings for %{name}
Group:         Development/OCaml
Requires:      %{name} = %{epoch}:%{version}-%{release}


%description -n ocaml-%{name}
ocaml-%{name} contains OCaml bindings for %{name}.

This is for toplevel and scripting access only.  To compile OCaml
programs which use %{name} you will also need ocaml-%{name}-devel.


%package -n ocaml-%{name}-devel
Summary:       OCaml bindings for %{name}
Group:         Development/OCaml
Requires:      ocaml-%{name} = %{epoch}:%{version}-%{release}


%description -n ocaml-%{name}-devel
ocaml-%{name}-devel contains development libraries
required to use the OCaml bindings for %{name}.


%package -n perl-%{name}
Summary:       Perl bindings for %{name}
Group:         Development/Perl
Requires:      %{name} = %{epoch}:%{version}-%{release}
Requires:      perl
Requires:      perl-XML-XPath


%description -n perl-%{name}
perl-%{name} contains Perl bindings for %{name}.


%package -n python-%{name}
Summary:       Python bindings for %{name}
Group:         Development/Perl
Requires:      %{name} = %{epoch}:%{version}-%{release}

%description -n python-%{name}
python-%{name} contains Python bindings for %{name}.


%package -n ruby-%{name}
Summary:       Ruby bindings for %{name}
Group:         Development/Ruby
Requires:      %{name} = %{epoch}:%{version}-%{release}
Provides:      ruby-guestfs = %{version}

%description -n ruby-%{name}
ruby-%{name} contains Ruby bindings for %{name}.


%package java
Summary:       Java bindings for %{name}
Group:         Development/Java
Requires:      %{name} = %{epoch}:%{version}-%{release}
Requires:      java >= 1.5.0
Requires:      jpackage-utils

%description java
%{name}-java contains Java bindings for %{name}.

If you want to develop software in Java which uses %{name}, then
you will also need %{name}-java-devel.


%package java-devel
Summary:       Java development package for %{name}
Group:         Development/Java
Requires:      %{name} = %{epoch}:%{version}-%{release}
Requires:      %{name}-java = %{epoch}:%{version}-%{release}

%description java-devel
%{name}-java-devel contains the tools for developing Java software
using %{name}.

See also %{name}-javadoc.


%package javadoc
Summary:       Java documentation for %{name}
Group:         Development/Java
Requires:      %{name} = %{epoch}:%{version}-%{release}
Requires:      %{name}-java = %{epoch}:%{version}-%{release}
Requires:      jpackage-utils

%description javadoc
%{name}-javadoc contains the Java documentation for %{name}.


%package -n php-%{name}
Summary:       PHP bindings for %{name}
Group:         Development/PHP
Requires:      %{name} = %{epoch}:%{version}-%{release}
Requires:      php

%description -n php-%{name}
php-%{name} contains PHP bindings for %{name}.

%package -n erlang-%{name}
Summary:       Erlang bindings for %{name}
Group:         Development/Erlang
Requires:      %{name} = %{epoch}:%{version}-%{release}

%description -n erlang-%{name}
erlang-%{name} contains Erlang bindings for %{name}.

%package -n gobject-%{name}
Summary:       Gobject bindings for %{name}
Group:         Development/Other
Requires:      %{name} = %{epoch}:%{version}-%{release}

%description -n gobject-%{name}
gobject-%{name} contains gobject bindings for %{name}.

%package -n lua-%{name}
Summary:       Lua bindings for %{name}
Group:         Development/Other
Requires:      %{name} = %{epoch}:%{version}-%{release}

%description -n lua-%{name}
lua-%{name} contains lua bindings for %{name}.

%package -n golang-%{name}
Summary:       Go bindings for %{name}
Group:         Development/Other
Requires:      %{name} = %{epoch}:%{version}-%{release}

%description -n golang-%{name}
golang-%{name} contains go bindings for %{name}.


%prep
%setup -q
%apply_patches
mkdir -p daemon/m4

autoreconf -fi

%build
%configure2_5x \
  --prefix=%{_prefix} --libdir=%{_libdir} \
  --mandir=%{_mandir} \
  --sysconfdir=%{_sysconfdir} \
  --with-qemu="qemu-kvm qemu-system-%{_build_arch} qemu" \
  --enable-supermin \
%if %{with_virtio}
  --with-drive-if=virtio \
%endif

# This ensures that /usr/sbin/chroot is on the path.  Not needed
# except for RHEL 5, it shouldn't do any harm on other platforms.
export PATH=/usr/sbin:$PATH

# 'INSTALLDIRS' ensures that perl libs are installed in the vendor dir
# not the site dir.
%make INSTALLDIRS=vendor DISTRO=MAGEIA

# Useful for debugging appliance problems.
#echo "==== files in initramfs ===="
#find initramfs -type f
echo "==== hostfiles ===="
ls -l appliance/supermin.d/hostfiles
cat appliance/supermin.d/hostfiles
echo "============"

%install
%make DESTDIR=$RPM_BUILD_ROOT install

# Delete the ordinary appliance, leaving just the supermin appliance.
rm -f $RPM_BUILD_ROOT%{_libdir}/guestfs/vmlinuz.*
rm -f $RPM_BUILD_ROOT%{_libdir}/guestfs/initramfs.*

# Delete static libraries, libtool files.
rm -f $RPM_BUILD_ROOT%{_libdir}/libguestfs.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libguestfs.la

# Clean up the examples/ directory which will get installed in %doc.
# Note we can't delete the original examples/Makefile because that
# will be needed by the check section later in the RPM build.
cp -a examples ex
pushd ex
make clean
rm Makefile*
rm -rf .deps .libs
popd

# Same for ocaml/examples.
cp -a ocaml/examples ocaml/ex
pushd ocaml/ex
make clean
rm Makefile*
popd

find $RPM_BUILD_ROOT -name perllocal.pod -delete
find $RPM_BUILD_ROOT -name .packlist -delete
find $RPM_BUILD_ROOT -name '*.bs' -delete
find $RPM_BUILD_ROOT -name 'bindtests.pl' -delete

rm -f $RPM_BUILD_ROOT%{python_sitearch}/libguestfsmod.a
rm -f $RPM_BUILD_ROOT%{python_sitearch}/libguestfsmod.la

if [ "$RPM_BUILD_ROOT%{python_sitearch}" != "$RPM_BUILD_ROOT%{python_sitelib}" ]; then
   mkdir -p $RPM_BUILD_ROOT%{python_sitelib}
   mv $RPM_BUILD_ROOT%{python_sitearch}/guestfs.py* \
     $RPM_BUILD_ROOT%{python_sitelib}/
fi

# Install ruby bindings by hand.
mkdir -p $RPM_BUILD_ROOT%{ruby_sitelibdir}
mkdir -p $RPM_BUILD_ROOT%{ruby_sitearchdir}
install -p -m0644 ruby/lib/guestfs.rb $RPM_BUILD_ROOT%{ruby_sitelibdir}
install -p -m0755 ruby/ext/guestfs/_guestfs.so $RPM_BUILD_ROOT%{ruby_sitearchdir}

# Remove static-linked Java bindings.
rm -f $RPM_BUILD_ROOT%{_libdir}/libguestfs_jni.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libguestfs_jni.la

# Move installed documentation back to the source directory so
# we can install it using a %%doc rule.
mv $RPM_BUILD_ROOT%{_docdir}/libguestfs installed-docs

# Remove Japanese manpages, since these are not translated fully at
# the moment.  When these are translated properly we intend to add
# them back.
rm -rf $RPM_BUILD_ROOT%{_mandir}/ja/man{1,3,5}/

# Find locale files.
%find_lang %{name}

%files -f %{name}.lang
%doc COPYING
%{_bindir}/libguestfs-test-tool
%{_sbindir}/libguestfs-make-fixed-appliance
%{_libdir}/guestfs/
%{_libdir}/libguestfs.so.*
#%{_libexecdir}/libguestfs-test-tool-helper
%{_mandir}/man1/libguestfs-*.1*
%{_mandir}/uk/man1/libguestfs-*.1*


%files devel
%doc BUGS ChangeLog HACKING TODO README
%doc ex html/guestfs.3.html html/pod.css
%doc installed-docs/*
%{_libdir}/libguestfs.so
%{_mandir}/man3/guestfs.3*
%{_mandir}/uk/man3/guestfs.3*
%{_mandir}/man3/guestfs-examples.3*
%{_mandir}/uk/man3/guestfs-examples.3*
%{_mandir}/man3/libguestfs.3*
%{_includedir}/guestfs.h
%{_libdir}/pkgconfig/libguestfs.pc


%files -n guestfish
%doc html/guestfish.1.html html/pod.css
%{_bindir}/guestfish
%{_mandir}/man1/guestfish.1*
%{_mandir}/uk/man1/guestfish.1*
#%dir %{_sysconfdir}/bash_completion.d
#%{_sysconfdir}/bash_completion.d/guestfish-bash-completion.sh


%files mount
%doc COPYING
%{_bindir}/guestmount
%{_mandir}/man1/guestmount.1*
%{_mandir}/uk/man1/guestmount.1*
%{_mandir}/man1/guestunmount.1*
%{_mandir}/uk/man1/guestunmount.1*
%{_bindir}/guestunmount


%files tools
%{_bindir}/virt-*
%{_mandir}/man1/virt-*.1*
%{_mandir}/uk/man1/virt-*.1*
%{_mandir}/man1/guestfs-*.1*
%{_mandir}/man5/libguestfs-tools*.5*
%{_mandir}/uk/man1/guestfs-*.1*
%{_mandir}/uk/man5/libguestfs-tools*.5*
%{_datadir}/bash-completion/*
%{_sysconfdir}/libguestfs-tools.conf

%files -n ocaml-%{name}
%doc README
%{_libdir}/ocaml/guestfs
%exclude %{_libdir}/ocaml/guestfs/*.a
%exclude %{_libdir}/ocaml/guestfs/*.cmxa
%exclude %{_libdir}/ocaml/guestfs/*.cmx
%exclude %{_libdir}/ocaml/guestfs/*.mli
%{_libdir}/ocaml/stublibs/*.so
%{_libdir}/ocaml/stublibs/*.so.owner


%files -n ocaml-%{name}-devel
%doc ocaml/ex
%{_mandir}/man3/guestfs-ocaml.3*
%{_mandir}/uk/man3/guestfs-ocaml.3*
%{_libdir}/ocaml/guestfs/*.a
%{_libdir}/ocaml/guestfs/*.cmxa
%{_libdir}/ocaml/guestfs/*.cmx
%{_libdir}/ocaml/guestfs/*.mli


%files -n perl-%{name}
%doc perl/examples
%{perl_vendorarch}/*
%{_mandir}/man3/Sys::Guestfs.3pm*
%{_mandir}/man3/guestfs-perl.3*
%{_mandir}/uk/man3/guestfs-perl.3*

%files -n python-%{name}
%doc README
%{python_sitearch}/*
%{python_sitelib}/*.py*
%{_mandir}/man3/guestfs-python.3*
%{_mandir}/uk/man3/guestfs-python.3*

%files -n ruby-%{name}
%doc README
%{ruby_sitelibdir}/guestfs.rb
%{ruby_sitearchdir}/_guestfs.so
%{_mandir}/man3/guestfs-ruby.3*
%{_mandir}/uk/man3/guestfs-ruby.3*

%files java
%doc README
%{_libdir}/libguestfs_jni*.so.*
%{_datadir}/java/*.jar


%files java-devel
%doc README
%{_libdir}/libguestfs_jni*.so
%{_mandir}/man3/guestfs-java.3*
%{_mandir}/uk/man3/guestfs-java.3*

%files javadoc
%doc README
%{_datadir}/javadoc/%{name}

%files -n php-%{name}
%doc php/README-PHP
%dir %{_sysconfdir}/php.d
%{_sysconfdir}/php.d/guestfs_php.ini
%{_libdir}/php/extensions/guestfs_php.so

%files -n erlang-%{name}
%{_bindir}/erl-guestfs
%{_libdir}/erlang/lib/libguestfs-*/ebin/*.beam
%{_mandir}/man3/guestfs-erlang.3*
%{_mandir}/uk/man3/guestfs-erlang.3*

%files -n gobject-%{name}
%{_includedir}/guestfs-gobject.h
%{_includedir}/guestfs-gobject/*
%{_libdir}/libguestfs-gobject-*
%{_libdir}/pkgconfig/libguestfs-gobject-1.0.pc
%{_libdir}/girepository-1.0/Guestfs-1.0.typelib
%{_datadir}/gir-1.0/*
%{_datadir}/gtk-doc/*

%files -n lua-%{name}
%{_libdir}/lua/*/*
%{_mandir}/man3/guestfs-lua.3*
%{_mandir}/uk/man3/guestfs-lua.3*

%files -n golang-%{name}
%{_libdir}/golang/*
%{_mandir}/man3/guestfs-golang.3*
%{_mandir}/uk/man3/guestfs-golang.3*


%changelog
* Mon Feb 24 2014 tmb <tmb> 1:1.24.5-1.1.mga4
+ Revision: 596624
- guestfish: change file requires to package requires (mga#12869)

* Fri Jan 24 2014 oden <oden> 1:1.24.5-1.mga4
+ Revision: 567708
- 1.24.5
- rediff patches

  + pterjan <pterjan>
    - Rebuild for new PHP

* Mon Jan 06 2014 dmorgan <dmorgan> 1:1.24.0-8.mga4
+ Revision: 565001
- Rebuild to please autobuild

* Thu Nov 28 2013 joequant <joequant> 1:1.24.0-7.mga4
+ Revision: 553811
- remove custom requires

* Thu Nov 28 2013 joequant <joequant> 1:1.24.0-6.mga4
+ Revision: 553804
- package libraries with readlink

* Mon Nov 25 2013 joequant <joequant> 1:1.24.0-5.mga4
+ Revision: 553073
- don't use custom requires for libguestfs

* Tue Nov 19 2013 colin <colin> 1:1.24.0-4.mga4
+ Revision: 551956
- Rebuild for new libdri

* Tue Nov 12 2013 tv <tv> 1:1.24.0-3.mga4
+ Revision: 550710
- requires supermin-helper in order to be able to mount disk images

* Wed Oct 23 2013 joequant <joequant> 1:1.24.0-2.mga4
+ Revision: 546691
- fix mandir error in build
- upgrade to 1.24.0 - fix 11497 - CVE 2013-4419

  + umeabot <umeabot>
    - Mageia 4 Mass Rebuild

* Mon Oct 14 2013 joequant <joequant> 1:1.23.31-1.mga4
+ Revision: 497105
- update to 1.23.31

* Thu Oct 10 2013 joequant <joequant> 1:1.23.28-1.mga4
+ Revision: 494749
- upgrade to 1.23.28

* Wed Oct 09 2013 joequant <joequant> 1:1.23.27-1.mga4
+ Revision: 494027
- add source package
- upgrade to 1.22.27 and golang

* Tue Oct 08 2013 colin <colin> 1:1.23.20-4.mga4
+ Revision: 493619
- Rebuild for new ncurses based termcap

* Thu Sep 26 2013 fwang <fwang> 1:1.23.20-3.mga4
+ Revision: 486526
- update file list
- rebuild for ruby 2.0

* Sun Sep 08 2013 joequant <joequant> 1:1.23.20-2.mga4
+ Revision: 476207
- add requires

* Mon Sep 02 2013 joequant <joequant> 1:1.23.20-1.mga4
+ Revision: 474327
- upgrade to 1.23.20

* Sat Aug 31 2013 fwang <fwang> 1:1.23.13-8.mga4
+ Revision: 473668
- rebuild for new sasl

* Sat Aug 24 2013 fwang <fwang> 1:1.23.13-7.mga4
+ Revision: 470446
- rebuild for new mesagl

* Mon Aug 19 2013 joequant <joequant> 1:1.23.13-6.mga4
+ Revision: 467602
- reduce description length

* Sat Aug 17 2013 joequant <joequant> 1:1.23.13-5.mga4
+ Revision: 467320
- bump to new supermin

* Sat Aug 17 2013 joequant <joequant> 1:1.23.13-4.mga4
+ Revision: 467154
- fix libintl dep

* Sat Aug 17 2013 fwang <fwang> 1:1.23.13-3.mga4
+ Revision: 467092
- drop invalid ruby req

* Fri Aug 16 2013 joequant <joequant> 1:1.23.13-2.mga4
+ Revision: 466909
- add build requires
- libguestfs fixes

* Wed Aug 14 2013 joequant <joequant> 1:1.23.13-1.mga4
+ Revision: 466430
- add buildrequires as pkgconfig
- add more build requires
- fix build requires
- fix libguestfs group
- add sources for libguestfs
- upgrade and update libguestfs
- revert deletion

  + saispo <saispo>
    - imported package libguestfs

